@@ -93,7 +93,7 @@ Use google etxt to speech, not too frequently. Creates an mp3 in /tmp and reads
         outfile="/tmp/msg_"+safe+".mp3"
         if not os.path.isfile(outfile):
             print("D... contacting google...")
-            tts=gTTS( self.message , lang=lang)
+            tts=gTTS( self.message+"." , lang=lang)
             tts.save(outfile)
         else:
             print("D... taking sound from /tmp/"+outfile)
