@@ -8,6 +8,8 @@ import os
 #----------------- text config file --------
 from configparser import ConfigParser
 
+import numpy as np
+
 """
 The trick:  In Botfather, create /newbot,
  - select a name Btrfs
@@ -108,6 +110,13 @@ def bot_send(section, bot_message, bot_photo="" ):
     #    bot_token = ''
     #    bot_chatID = ''
 
+
+    ### filename = ""
+    if (type(bot_photo)==np.ndarray):
+        filename = os.path.expanduser( f"/tmp/flashcam_%Y%m%d_%H%M%S.jpg" )
+        cv2.imwrite(filename, bot_photo)
+        bot_photo = filename
+
     if (bot_photo==""): #======= NO PHOTO =============
         url='https://api.telegram.org/bot' + bot_token + '/sendMessage'
         payload = {'chat_id':bot_chatID,
